bbprep.selectors
================

.. automodule:: bbprep.selectors

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: class.rst
      :nosignatures:
   
      AllNonHSelector
      AllSelector
      BindersSelector
      ByIdSelector
      BySmartsSelector
      DeletersSelector
      NotPlacersSelector
      NullSelector
      Selector
      XCOMXSelector
   
   

   
   
   



